# crewAI



## Usage


```
pip install crewai
pip install duckduckgo-search

import os
from crewai import Agent, Task, Crew, Process

os.environ["OPENAI_API_KEY"] = "YOUR KEY"

from langchain.tools import DuckDuckGoSearchRun
search_tool = DuckDuckGoSearchRun()

# 定义一个拥有 DuckDuckGoSearchRun 搜索归纳功能的 Agent
researcher = Agent(
  role='Senior Research Analyst', # 高级研究分析师
  goal='Uncover cutting-edge developments in AI and data science in',
  backstory="""You work at a leading tech think tank.
  Your expertise lies in identifying emerging trends.
  You have a knack for dissecting complex data and presenting
  actionable insights.""",
  verbose=True,
  allow_delegation=False,
  tools=[search_tool]
)

# 定义一个
writer = Agent(
  role='Tech Content Strategist', # 技术内容策略师
  goal='Craft compelling content on tech advancements',
  backstory="""You are a renowned Content Strategist, known for
  your insightful and engaging articles.
  You transform complex concepts into compelling narratives.""",
  verbose=True,
  allow_delegation=True,
  # (optional) llm=ollama_llm
)

# 任务一，通过 DuckDuckGoSearchRun 搜索引擎归纳关键词
task1 = Task(
  description="""Conduct a comprehensive analysis of the latest advancements in AI in 2024.
  Identify key trends, breakthrough technologies, and potential industry impacts.
  Your final answer MUST be a full analysis report""",
  agent=researcher
)

# 任务二，基于任务一的归纳，写一篇博客
task2 = Task(
  description="""Using the insights provided, develop an engaging blog
  post that highlights the most significant AI advancements.
  Your post should be informative yet accessible, catering to a tech-savvy audience.
  Make it sound cool, avoid complex words so it doesn't sound like AI.
  Your final answer MUST be the full blog post of at least 4 paragraphs.""",
  agent=writer
)

# 定义
crew = Crew(
  agents=[researcher, writer],
  tasks=[task1, task2],
  verbose=2, # You can set it to 1 or 2 to different logging levels
)

# 执行
result = crew.kickoff()

print("######################")
print(result)
```